@@ -53,7 +53,7 @@ sjog_sonypi_read(gpointer * data)
 //        sjog_jog_position_changed(JOG_PUSHED);
 //        break;
      case SONYPI_EVENT_JOGDIAL_PRESSED:
-//        sjog_button_faketap(2);      
+        sjog_button_faketap(2);      
 	//lastevent = SONYPI_EVENT_JOGDIAL_PRESSED ;
         break;
 
